__author__ = 'Carlos Vigo <carviher1990@gmailcom>'
__email__ = '<carlosv@phys.ethz.ch>'
__short_author__ = 'Carlos Vigo'
__copyright__ = '2021, Carlos Vigo'
__package_name__ = 'pdf-importer'
__module_name__ = 'pdf_importer.py'
__project_name__ = 'Statement PDF Importer'
__url__ = 'https://github.com/c-vigo/StatementPDFImporter'
__documentation__ = 'https://github.com/c-vigo/StatementPDFImporter'
__version__ = '0.4'
__short_version__ = '0.4'
__description__ = 'A PDF importer to generate CSV files from bank statements'

